;/----------------------------------------------------------------------
;/ Name       PureXml
;/ Version    0.1
;/ Date       Feb. 2005
;/            
;/ Descr.     A Purebasic XML Userlibrary based on the 'xmlparser.dll'
;/            Written by Philippe Carpentier - flype@altern.org
;/            
;/ Env.       Compiled with Purebasic 3.93 Beta 3
;/            This source need the xmlparser.dll
;/----------------------------------------------------------------------


;/
;/ Constantes
;/

#XML_NODE_TAG     =  0
#XML_NODE_DATA    =  1
#XML_NODE_COMMENT =  2
#XML_NODE_INVALID = -1

;/
;/ Private Variables
;/

Structure PureXml_Struct
  
  Node.l
  PrevNode.l
  
  handler_Open.l
  handler_Close.l
  handler_Data.l
  handler_Comment.l
  handler_Invalid.l
  
EndStructure

Global PureXml.PureXml_Struct

;/
;/ Private Procedures
;/

Procedure.l PureXml_OpenHandler()
  
  If PureXml\handler_Open
    CallFunctionFast(PureXml\handler_Open)
  EndIf
  
EndProcedure
Procedure.l PureXml_CloseHandler()
  
  If PureXml\handler_Close
    CallFunctionFast(PureXml\handler_Close)
  EndIf 
  
EndProcedure
Procedure.l PureXml_DataHandler()
  
  If PureXml\handler_Data
    CallFunctionFast(PureXml\handler_Data)
  EndIf 
  
EndProcedure
Procedure.l PureXml_CommentHandler()
  
  If PureXml\handler_Comment
    CallFunctionFast(PureXml\handler_Comment)
  EndIf
  
EndProcedure
Procedure.l PureXml_InvalidHandler()
  
  If PureXml\handler_Invalid
    CallFunctionFast(PureXml\handler_Invalid)
  EndIf
  
EndProcedure

Procedure.l PureXml_Parent()
  
  PureXml\Node = XMLParent_(PureXml\Node)
  ProcedureReturn PureXml\Node
  
EndProcedure
Procedure.l PureXml_Child()
  
  x = XMLChild_(PureXml\Node)
  
  If x
    PureXml\Node = x
    ProcedureReturn PureXml\Node
  Else
    PureXml_CloseHandler()
    ProcedureReturn PureXml\PrevNode
  EndIf
  
EndProcedure
Procedure.l PureXml_Next()
  
  PureXml\Node = XMLNextSibling_(PureXml\Node)
  ProcedureReturn PureXml\Node
  
EndProcedure
Procedure.b PureXml_Parser()
  
  Repeat
    
    Select XMLNodeType_(PureXml\Node)
      Case #XML_NODE_TAG     : PureXml_OpenHandler() : PureXml_Child()
      Case #XML_NODE_DATA    : PureXml_DataHandler()
      Case #XML_NODE_COMMENT : PureXml_CommentHandler()
      Case #XML_NODE_INVALID : PureXml_InvalidHandler()
    EndSelect
    
    PureXml\PrevNode = PureXml\Node
    
    If PureXml_Next() = #Null
      
      PureXml\Node = PureXml\PrevNode
      PureXml_Parent()
      PureXml_CloseHandler()
      
      If PureXml_Next() = #Null
        ProcedureReturn #True
      EndIf
      
    EndIf
    
  ForEver
  
EndProcedure

;/
;/ Public Procedures
;/

ProcedureDLL.s PureXml_LastError()
  
  ProcedureReturn PeekS(XMLzLastError_())
  
EndProcedure
ProcedureDLL.s PureXml_Name()
  
  ProcedureReturn PeekS(XMLzGetTag_(PureXml\Node))
  
EndProcedure
ProcedureDLL.s PureXml_Data()
  
  ProcedureReturn PeekS(XMLzChildData_(PureXml\Node))
  
EndProcedure
ProcedureDLL.s PureXml_Attr(attrName.s)
  
  ProcedureReturn PeekS(XMLzAttribValue_(PureXml\Node,attrName))
  
EndProcedure

ProcedureDLL.b PureXml_ParseFile(xmlFile.s)
  
  PureXml\Node = XMLzParseFile_(xmlFile)
  
  If PureXml\Node
    ProcedureReturn PureXml_Parser()
  EndIf
  
EndProcedure
ProcedureDLL.b PureXml_ParseString(xmlString.s)
  
  PureXml\Node = XMLzParse_(xmlString)
  
  If PureXml\Node
    ProcedureReturn PureXml_Parser()
  EndIf
  
EndProcedure

ProcedureDLL.l PureXml_SetOpenHandler(funcPtr.l)
  
  PureXml\handler_Open = funcPtr
  
EndProcedure
ProcedureDLL.l PureXml_SetCloseHandler(funcPtr.l)
  
  PureXml\handler_Close = funcPtr
  
EndProcedure
ProcedureDLL.l PureXml_SetDataHandler(funcPtr.l)
  
  PureXml\handler_Data = funcPtr
  
EndProcedure
ProcedureDLL.l PureXml_SetCommentHandler(funcPtr.l)
  
  PureXml\handler_Comment = funcPtr
  
EndProcedure
ProcedureDLL.l PureXml_SetInvalidHandler(funcPtr.l)
  
  PureXml\handler_Invalid = funcPtr
  
EndProcedure

;/
;/ End of PureXml Userlibrary
;/
; ExecutableFormat=
; EOF